========================
ChangeTip Python Library
========================

A set of tools for interacting with the [ChangeTip](https://www.changetip.com) API.

Install
=======
.. code-block:: bash

    $ pip install slacker


Examples
========
TODO


Tests
=====
CircleCI test status:

.. image:: https://circleci.com/gh/changecoin/changetip-python.svg?style=svg
    :target: https://circleci.com/gh/changecoin/changetip-python


To run tests:

.. code-block:: bash

    $ python setup.py test


License
=======
MIT
